<?php

/*
Plugin Name: f&raquo;dforward
Plugin URI: http://wordpress.rebelic.nl/feedforward/
Description: This plugin enables your blog to join the f&raquo;dforward recommendation network. After installation, a widget will show at the bottom of each article, which will recommend related articles based on the content of the current article and on the interests of your readers. With f&raquo;dforward you can become part of other blog networks to share your content or you can create your own network. After activation here, proceed to the settings menu to let your widget join the network.
Author: Timan Rebel
Version: 1.1
Author URI: http://wordpress.rebelic.nl/
*/

/**
 * Adds the required javascript code to the page.
 *
 */
function ff_addscript() {
    //only add when on single post page
    if(is_single()) {
?>
    <!-- feedforward -->
    <script type="text/javascript" src="http://feedforward.kimengi.com:80/js/start-script.htm"></script>
<?php
    }
}

/**
 * Adds the Feedforward HTML code to the end of a post
 *
 * @param string $_c
 * @return string
 */
function ff_addhtml($_c) {
    $ff_html = '';

    //only add when on single post page
    if(is_single()) {
        $options = get_option('feedforward');

        //only add when an avatar has been retrieved
        if( !empty($options['avatar']) ){
            $ff_html = "\n\n"
                 . "      <!-- feedforward -->\n"
                 . "      <object id=\"feedforward\"><param name=\"avatar\" value=\"".$options['avatar']."\"/></object>\n\n";
        }
    }

    return $_c . $ff_html;
}

/**
 * Builds the Config page for Feedforward.
 *
 */
function ff_configpage() {
    //Get our options and see if we're handling a form submission.
    $options = get_option('feedforward');

    //
    $errorOccurred = false;

    //Get the last post
    $my_query = new WP_Query('post_status=\'publish\'&showposts=1');
    while ($my_query->have_posts()) : $my_query->the_post();
        $lastpostid = $post->ID;
    endwhile;

    echo '<div class="wrap">';
    if( function_exists('screen_icon') ) {
        echo screen_icon();
    }
    echo '<h2>f&raquo;dforward Settings</h2>';


    if (!is_array($options) ) {
        //when not installed, request avatar
        require_once(ABSPATH.WPINC.'/class-snoopy.php');
        $snoop = new Snoopy();
        $snoop->agent = 'FeedForward Wordpress plugin';
        $snoop->submit(
            'http://feedforward.kimengi.com/admin/request-new-owner.htm'
            , array(
                'sitename'          => get_option('blogname'),
                'url'               => get_option('siteurl'),
                'lastpermalink'     => get_permalink($lastpostid)
            )
        );
        if (strpos($snoop->response_code, '200')) {
            $result = $snoop->results;

            //trim whitespaces
            $result = trim($result);

            //check for errors
            if( strpos($result, 'new blog owner created') === false ) {
                $errorOccurred = true;

                $resultTemp = nl2br($result);
                $resultArray = explode('<br />', $resultTemp);
                $tempStuff = explode(' ', $resultArray[1]);
                $result = $tempStuff[0];

                echo '  <p><strong>Error recieved while registering your widget</strong><br />
                        Received error \''. trim($result) .'\' Please contact f&raquo;dforward at <a href="mailto:support@kimengi.com">support@kimengi.com</a></p>';

            } else {
                $resultTemp = nl2br($result);
                $resultArray = explode('<br />', $resultTemp);
                $tempStuff = explode(' ', $resultArray[0]);
                $result = $tempStuff[0];
                $result = trim($result);

                $ff_values = explode(':', $result);

                $options = array('website'    => get_option('blogname'),
                                 'language'   => 'en',
                                 'skin'       => 'wh',
                                 'stealth'    => 'no',
                                 'avatar'     => $ff_values[0],
                                 'cookie'     => $ff_values[1]);

                update_option('feedforward', $options);
            }
        } else {
            $errorOccurred = true;
?>
    <p><strong>Error recieved while registering your widget</strong><br />
    An error occured while registering your plugin with the f&raquo;dforward servers. Please reload this page...</p>
<?php
        }
    }

    //html for options page
    if( !$errorOccurred ) {
?>
  <p>Thanks for activating fdforward on your blog.</p>
  <p>You are one step away from joining the network. Please agree with the terms below and click the button to continue with the configuration of your widget.</p>
  <p>I accept and agree with the following terms:</p>
  <form method="GET" action="http://feedforward.kimengi.com/admin/assume-identity.htm">
    <fieldset class="options">
      <p>
        <input type="checkbox" name="accept1" value="true" /> <a href="http://www.kimengi.com/faq/terms-of-use/general-terms-of-use-english.html">Terms Of Use (for general use of the widget)</a>
      </p>
      <p>
        <input type="checkbox" name="accept2" value="true" /> <a href="http://www.kimengi.com/faq/terms-of-use/affiliate-terms-english.html">Affilate Terms (for joining the network)</a>
      </p>
      <p class="submit">
        <input type="submit" name="ff-submit" value="Join f&raquo;dforward" />
      </p>
    </fieldset>

  <input type="hidden" name="avatar" value="<?php echo $options['avatar'] ?>" />
  <input type="hidden" name="cookie" value="<?php echo $options['cookie'] ?>" />
  <input type="hidden" name="url" value="<?php echo get_permalink($lastpostid); ?>" />
  </form>
<?php
    }
}

/**
 * Adds the link to the menu in Wordpress' admin
 *
 */
function ff_configpagelink() {
  if (function_exists('add_options_page')) {
    add_options_page('feedforward', 'f&raquo;dforward', 8, basename(__FILE__), 'ff_configpage');
  }
}

function ff_filter_plugin_actions( $links, $file ){
        //Static so we don't call plugin_basename on every plugin row.
        static $this_plugin;
    if ( ! $this_plugin ) $this_plugin = plugin_basename(__FILE__);

        if ( $file == $this_plugin ){
                $settings_link = '<a href="options-general.php?page=feedforward.php">' . __('Settings') . '</a>';
                array_unshift( $links, $settings_link ); // before other links
        }
        return $links;
}
add_filter( 'plugin_action_links', 'ff_filter_plugin_actions', 10, 2 );


//add javascript to head of page
if (function_exists('add_action')) {
    add_action('wp_head', 'ff_addscript');
}

if (function_exists('add_filter')) {
    //add filter with low priority
    add_filter('the_content', 'ff_addhtml', 1000);
}

# add config page
if (function_exists('add_action')) {
    add_action('admin_menu', 'ff_configpagelink');
}

?>
